ExecutorParams

Struct ExecutorParams 

pub struct ExecutorParams {
    pub libraries: Dict<HashBytes, LibDescr>,
    pub rand_seed: HashBytes,
    pub block_unixtime: u32,
    pub block_lt: u64,
    pub prev_mc_block_id: Option<BlockId>,
    pub vm_modifiers: BehaviourModifiers,
    pub disable_delete_frozen_accounts: bool,
    pub charge_action_fees_on_fail: bool,
    pub full_body_in_bounced: bool,
    pub strict_extra_currency: bool,
    pub authority_marks_enabled: bool,
}
Executor configuration parameters.

Fields

libraries: Dict<HashBytes, LibDescr>

Public libraries from the referenced masterchain state.

rand_seed: HashBytes

Rand seed of the block.

block_unixtime: u32

Unix timestamp in seconds of the block.

block_lt: u64

Logical time of the block.

prev_mc_block_id: Option<BlockId>

Last known previous masterchain block before current.

vm_modifiers: BehaviourModifiers

VM behaviour modifiers.

disable_delete_frozen_accounts: bool

Prevent Frozen accounts from being deleted when their storage due is too high.

charge_action_fees_on_fail: bool

Charge account balance for additional total_action_fees when action phase fails.

full_body_in_bounced: bool

Attaches an original message body as an additional cell to a bounced message body.

strict_extra_currency: bool

More gas-predictable extra currency behaviour.

authority_marks_enabled: bool

Whether accounts can be suspended by authority marks.