pub struct TransactionMeta {
pub total_fees: Tokens,
pub out_msgs: Vec<Lazy<OwnedMessage>>,
pub next_lt: u64,
}Expand description
Short transaction description.
Fields
total_fees: TokensA sum of all collected fees from all phases.
out_msgs: Vec<Lazy<OwnedMessage>>List of outbound messages.
next_lt: u64Minimal logical time for the next transaction on this account.