pub struct ExecutorInspector<'e> {
pub actions: Option<Cell>,
pub public_libs_diff: Vec<PublicLibraryChange>,
pub exit_code: Option<i32>,
pub missing_library: Option<HashBytes>,
pub total_gas_used: u64,
pub debug: Option<&'e mut dyn Write>,
pub modify_smc_info: Option<&'e mut ModifySmcInfoFn>,
}Expand description
Executor internals inspector.
Fields
actions: Option<Cell>Actions list from compute phase.
public_libs_diff: Vec<PublicLibraryChange>A set of changes of the public libraries dict.
NOTE: The order is the same as the actions order so it can contain duplicates and must be folded before use.
exit_code: Option<i32>Compute phase exit code.
missing_library: Option<HashBytes>Hash of the library in case it was missing during execution.
total_gas_used: u64Total gas consumed (including the remaining “free” gas and everything that exceeds the limit).
debug: Option<&'e mut dyn Write>Debug output target.
modify_smc_info: Option<&'e mut ModifySmcInfoFn>Hook for a compute phase to modify C7 register data.