pub struct UncommittedTransaction<'a, 's> { /* private fields */ }Expand description
Executed transaction.
Implementations
Sourceimpl<'a, 's> UncommittedTransaction<'a, 's>
impl<'a, 's> UncommittedTransaction<'a, 's>
pub fn with_info( exec: ExecutorState<'a>, original: &'s ShardAccount, in_msg: Option<Cell>, info: impl Into<TxInfo>, ) -> Result<Self>
Sourcepub fn build_uncommitted(&self) -> Result<Transaction, Error>
pub fn build_uncommitted(&self) -> Result<Transaction, Error>
Creates a partially finalized transaction.
It differs from the normal transaction by having a stub state_update
and possibly denormalized end_status.
Sourcepub fn commit(self) -> Result<ExecutorOutput>
pub fn commit(self) -> Result<ExecutorOutput>
Creates a final transaction and a new contract state.